"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Return a function to construct a class object without 'new'.
 *
 * @example
 * ```
 *     class A {
 *       constructor(a: numbber, b: string) {}
 *     }
 *
 *     const AA = noNew(A);
 *     const a = AA(1, 'abc'); // same as new A(1, 'abc');
 * ```
 */
function noNew(c) {
    return new Proxy(c, {
        apply(target, args, argumentsList) {
            return new target(...argumentsList);
        },
    });
}
exports.default = noNew;
